<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 *  Asps Check Referrer
 *
 *  This very simple example of a Text Filter will parse
 *  printed text, blacking out words perceived to be bad
 *
 * @package    filter
 * @subpackage aspscheckreferrer
 * @copyright  2004 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

//////////////////////////////////////////////////////////////
//  Asps Check Referrer
//
//  General Use - Block access from defined IPs/Referrers to defined Sections/Urls. If no Sections/Urls defined, block access to all site from defined IPs/Referrers. 
//  ASPS Use - Allow access from defined IPs/Referrers to defined Sections/Urls. If no Sections/Urls defined, allow access to all site only from defined IPs/Referrers. 
//
//
//////////////////////////////////////////////////////////////

class filter_aspscheckreferrer extends moodle_text_filter {
    
    function filter($text, array $options = array()){
        global $CFG;
        if ( ! is_siteadmin() )
        {
            $url = $_SERVER["HTTP_HOST"] . $_SERVER["REQUEST_URI"];
            $referrer = !empty ( $_SERVER["HTTP_REFERER"] ) ? $_SERVER["HTTP_REFERER"] : '';
            $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
            if ( !empty( $_SERVER['X_FORWARDED_FOR'] ) )
            {
                $X_FORWARDED_FOR = explode( ',', $_SERVER['X_FORWARDED_FOR'] );
                if ( !empty( $X_FORWARDED_FOR ) )
                {
                    $REMOTE_ADDR = trim($X_FORWARDED_FOR[0]);
                }
            }
            elseif ( !empty( $_SERVER['HTTP_X_FORWARDED_FOR'] ) )
            {
                $HTTP_X_FORWARDED_FOR = explode( ',', $_SERVER['HTTP_X_FORWARDED_FOR'] );
                if ( !empty( $HTTP_X_FORWARDED_FOR ) )
                {
                    $REMOTE_ADDR = trim( $HTTP_X_FORWARDED_FOR[0] );
                }
            }
            $user_ip = preg_replace('/[^0-9a-f:\., ]/si', '', $REMOTE_ADDR);
            
            $usage = isset( $CFG->filter_aspscheckreferrer_use ) ? $CFG->filter_aspscheckreferrer_use : 1;
            $asps_get_ips = isset( $CFG->filter_aspscheckreferrer_ips ) ? $CFG->filter_aspscheckreferrer_ips : '';
            $asps_get_referrers = isset( $CFG->filter_aspscheckreferrer_referrers ) ? $CFG->filter_aspscheckreferrer_referrers : '';
            $asps_get_urls = isset( $CFG->filter_aspscheckreferrer_urls ) ? $CFG->filter_aspscheckreferrer_urls : '';
            $asps_get_sections = isset( $CFG->filter_aspscheckreferrer_sections ) ? $CFG->filter_aspscheckreferrer_sections : '';
            
            $asps_get_ips = str_replace( ' ', '', $asps_get_ips );
            $asps_get_referrers = str_replace( ' ', '', $asps_get_referrers );
            $asps_get_urls = str_replace( ' ', '', $asps_get_urls );
            $asps_get_sections = str_replace( ' ', '', $asps_get_sections );
            
            $asps_ips = explode( ',', $asps_get_ips );
            $asps_referrers = explode( ',', $asps_get_referrers );
            $asps_urls = explode( ',', $asps_get_urls );
            $asps_sections = explode( ',', $asps_get_sections );
            
            if ( !empty( $asps_get_urls ) )
            {
                foreach ( $asps_urls as $asps_url )
                {
                    $asps_url = str_replace( 'http://', '', $asps_url );
                    $asps_url = str_replace( 'https://', '', $asps_url );
                    $asps_url = rtrim( $asps_url, "/" );
            
                    $url = str_replace( 'http://', '', $url );
                    $url = str_replace( 'https://', '', $url );
                    $url = rtrim( $url, "/" );
            
                    if ( $url == $asps_url )
                    {
                        $url_found = 1;
                        break;
                    }
                }
            }
            if ( !empty( $asps_get_sections ) )
            {
                foreach ( $asps_sections as $asps_section )
                {
                    $asps_section = str_replace( 'http://', '', $asps_section );
                    $asps_section = str_replace( 'https://', '', $asps_section );
                    if ( false !== strpos( $url, $asps_section ) || '/' == $asps_section )
                    {
                        $section_found = 1;
                        break;
                    }
                }
            }
            if ( !empty( $asps_get_referrers ) )
            {
                foreach ( $asps_referrers as $asps_referrer )
                {
                    $asps_referrer = str_replace( 'http://', '', $asps_referrer );
                    $asps_referrer = str_replace( 'https://', '', $asps_referrer );
                    $asps_referrer = rtrim( $asps_referrer, "/" );
            
                    $referrer = str_replace( 'http://', '', $referrer );
                    $referrer = str_replace( 'https://', '', $referrer );
                    $referrer = rtrim( $referrer, "/" );
            
                    if ( $referrer == $asps_referrer )
                    {
                        $referrer_found = 1;
                        break;
                    }
                }
            }
            if ( !empty( $asps_get_ips ) )
            {
                if ( in_array( $user_ip, $asps_ips ) )
                {
                    $ip_found = 1;
                }
            }
            
            
            if ( 2 == $usage )
            {
                //ASPS Use - Allow access from defined IPs/Referrers to defined Sections/Urls. If no Sections/Urls defined, allow access to all site only from defined IPs/Referrers. 
                if ( ! empty( $asps_get_urls ) || ! empty( $asps_get_sections ) )
                {
                    if ( ! empty( $url_found ) || !empty( $section_found ) )
                    {
                        if ( empty( $ip_found ) && empty( $referrer_found ) )
                        {
                            $restrict = 1;
                        }
                    }
                }
            }
            else
            {
                //General Use - Block access from defined IPs/Referrers to defined Sections/Urls. If no Sections/Urls defined, block access to all site from defined IPs/Referrers. 
                if ( empty( $asps_get_urls ) && empty( $asps_get_sections ) )
                {
                    if ( !empty( $ip_found ) || !empty( $referrer_found ) )
                    {
                        $restrict = 1;
                    }
                }
                else
                {
                    if ( ! empty( $url_found ) || !empty( $section_found ) )
                    {
                        if ( !empty( $ip_found ) || !empty( $referrer_found ) )
                        {
                            $restrict = 1;
                        }
                    }
                }
            }
            
            //change this to ww9.info after curl_setopt($ch, CURLOPT_REFERER, "ww9.info");
            if ( 'http://demo.ww9.info/' == strtolower( $referrer ) || 'ww9.info/' == strtolower( $referrer ) || 'http://ww9.info/' == strtolower( $referrer ) )
            {
                $restrict = '0';
            }
            
            if ( !empty( $restrict ) )
            {
                ?>
                    <html>
                    <head>
                    <title>ASPS : Restricted Access</title>
                    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
                    
                    
                    </head>
                    
                    <body bgcolor="#FFFFFF">
                    <table border="0" cellpadding="10" cellspacing="0" width="100%">
                    <tr>
                    <td align="center" rowspan="2" valign="top">
                    <br>
                          <img src="/filter/aspscheckreferrer/artisbrowser256_shaped.png" width="187" height="170"> <br>
                          <br>
                          <font size="5"><b>Direct Access Not Permitted<br>
                          </b></font> &nbsp; 
                          <div align="center">
                    
                    <br>
                    <table width="680" border="0" cellspacing="0" cellpadding="0">
                    	      <tr> 
                                <td align="center"> 
                                  <p>The page that you requested cannot be accessed directly. <br>
                                    <br>
                                    Please return to this site's <a href="<?php echo $CFG->wwwroot; ?>" target="_top">home 
                                    page</a> to find more appropriate links for this content.</p>
                                  <p><br>
                                    <br>
                                    <br>
                                    Copyright &#169; 2017 <a href="http://www.artistscope.com" target="_blank">ArtistScope</a>. 
                                    All Rights Reserved. </p>
                                </td>
                    	</tr>
                    </table>
                    </div>
                    
                    </td>
                    </tr>
                    </table>
                    
                    </body>
                    </html>
                <?php
                die();
            }
            else
            {
                return $text;
            }   
            
        }
        else
        {
            return $text;
        }
    }
}


